/* Écriture des diverses données numériques pour le programme SONDE esclave :
• Les tableaux de consignes de 0000 à 0431.
• Les 24 octets à partir de 0024 sont disponibles car actuellement non utilisés.
• Balayage télémétrique 0432 à 0463.
• Spectre colorimétrique de 0464 à 0477.
• P1 en 480, P2 en 512, P3 en 544 sont effacés.
• P4 en 576, P5 en 608, P6 en 640, P7 en 672, P8 en 704, P9 en 736 contiennent des programmes cohérents.
• Inscrit huit postures cohérentes dont quatre originales.

Ce programme commence par purger intégralement l'EEPROM pour partir de l'équivalent d'une
EEPROM vierge. Ainsi on peut la lister et en modification de PGM en observer les effets.

                                                                PGM            RAM dynamique                                                        
  Démonstrateur initial gérant uniquement le clavier :    8838 Octets (28%)   252 Octets (12%)
*/

#include <avr/eeprom.h> // Bibliothèque intégrée à l'IDE qui gère les entiers ,les réels ...

byte Compteur; // Compteur pour séparer les tableaux dans l'affichage sur le Moniteur de l'IDE.
int PTR; // Pointeur des octets situés en EEPROM. (Pointe le premier emplacement libre.)
int MAX_Octets_dans_tableaux = 408; // 24 x Nb Tableaux. (Ici 17 configurations.)

void setup() {Serial.begin(115200);}

void loop() {
//  goto Juste_LIRE_EEPROM;
  //-----------------------------------------------------------------------------------
  // Ci-dessous : Possibilité de "purger une zone avec des #FF.
  for (int I=0; I < 1024; I++) Ecrire_un_Entier_en_EEPROM(I,255);
  //-----------------------------------------------------------------------------------
  PTR = 0; // Les données sont rangées à partir du début de l'EEPROM. 
  // 01 ------------- Tableau de configuration STABLE Raisonnable. (000) -------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 305); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 274); Ecrire_un_Entier_en_EEPROM(PTR, 406); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 287); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 285); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 02 ------------------------------------------------------ (024) --------------   (Place disponible car posture inutilisée)
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255); Ecrire_un_OCTET_en_EEPROM(PTR, 255);
  Afficher_PTR();
  // 03 ------------------ Tableau des Neutres opérationnels. (048) -------------------
  Ecrire_un_Entier_en_EEPROM(PTR, 320); Ecrire_un_Entier_en_EEPROM(PTR, 308); Ecrire_un_Entier_en_EEPROM(PTR, 316); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 289); Ecrire_un_Entier_en_EEPROM(PTR, 303); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 262); Ecrire_un_Entier_en_EEPROM(PTR, 292); Ecrire_un_Entier_en_EEPROM(PTR, 310); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 300); Ecrire_un_Entier_en_EEPROM(PTR, 285); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe D.
  Afficher_PTR(); 
  // 04 ------------------ Tableau de Configuration Décollage. (072) ------------------ 
  Ecrire_un_Entier_en_EEPROM(PTR, 211); Ecrire_un_Entier_en_EEPROM(PTR, 152); Ecrire_un_Entier_en_EEPROM(PTR, 315); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 400); Ecrire_un_Entier_en_EEPROM(PTR, 418); Ecrire_un_Entier_en_EEPROM(PTR, 232); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 159); Ecrire_un_Entier_en_EEPROM(PTR, 139); Ecrire_un_Entier_en_EEPROM(PTR, 255); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 411); Ecrire_un_Entier_en_EEPROM(PTR, 463); Ecrire_un_Entier_en_EEPROM(PTR, 325); // Jambe D.
  Afficher_PTR(); 
  // 05 ---------------- Tableau de Configuration Atterrissage. (096) ----------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 303); Ecrire_un_Entier_en_EEPROM(PTR, 490); Ecrire_un_Entier_en_EEPROM(PTR, 154); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 303); Ecrire_un_Entier_en_EEPROM(PTR, 141); Ecrire_un_Entier_en_EEPROM(PTR, 481); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 303); Ecrire_un_Entier_en_EEPROM(PTR, 472); Ecrire_un_Entier_en_EEPROM(PTR, 145); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 303); Ecrire_un_Entier_en_EEPROM(PTR, 134); Ecrire_un_Entier_en_EEPROM(PTR, 501); // Jambe D.
  Afficher_PTR();
  // 06 ------------- Tableau de configuration STABLE Transversale. (120)-------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 227); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 376); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR(); 
  // 07 -------------- Tableau de configuration Hauteur Maximale. (144)--------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 152); Ecrire_un_Entier_en_EEPROM(PTR, 230); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 483); Ecrire_un_Entier_en_EEPROM(PTR, 391); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 145); Ecrire_un_Entier_en_EEPROM(PTR, 232); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 458); Ecrire_un_Entier_en_EEPROM(PTR, 398); // Jambe D.
  Afficher_PTR();
  // 08 ----------------- Configuration "Avancée" pour Reculer. (168) ----------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 274); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 379); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 187); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 311); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 09 ------------------------- Configuration de VEILLE. (192) ---------------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 309); Ecrire_un_Entier_en_EEPROM(PTR, 427); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 294); Ecrire_un_Entier_en_EEPROM(PTR, 186); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 307); Ecrire_un_Entier_en_EEPROM(PTR, 435); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 272); Ecrire_un_Entier_en_EEPROM(PTR, 194); // Jambe D.
  Afficher_PTR();
  // 10 ---------------------- Configuration pointage LASER. (216) -------------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 312); Ecrire_un_Entier_en_EEPROM(PTR, 314); Ecrire_un_Entier_en_EEPROM(PTR, 135); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 171); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 11 --------------------- Configuration Retour de LASER. (240) -------------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 171); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 12 ------------------ Configuration "Reculée" pour Avancer. (264) ---------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 204); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 309); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 257); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 381); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 13 ------------------ Configuration avant Hauteur Maximale. (288) ---------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 264); Ecrire_un_Entier_en_EEPROM(PTR, 449); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 347); Ecrire_un_Entier_en_EEPROM(PTR, 167); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 262); Ecrire_un_Entier_en_EEPROM(PTR, 464); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 312); Ecrire_un_Entier_en_EEPROM(PTR, 158); // Jambe D.
  Afficher_PTR();
  // 14 ------------------- Configuration pour Tourner à Droite. (312) ---------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 269); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 374); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 252); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 376); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 15 ------------------- Configuration pour Tourner à Gauche. (336) ---------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 209); Ecrire_un_Entier_en_EEPROM(PTR, 213); Ecrire_un_Entier_en_EEPROM(PTR, 307); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 314); Ecrire_un_Entier_en_EEPROM(PTR, 414); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 192); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 319); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 316); Ecrire_un_Entier_en_EEPROM(PTR, 388); Ecrire_un_Entier_en_EEPROM(PTR, 314); // Jambe D.
  Afficher_PTR();
  // 16 ------------------- Configuration pour Décaler à Droite. (360) ---------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 270); Ecrire_un_Entier_en_EEPROM(PTR, 281); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 339); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 215); Ecrire_un_Entier_en_EEPROM(PTR, 439); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 381); Ecrire_un_Entier_en_EEPROM(PTR, 188); // Jambe D.
  Afficher_PTR();
  // 17 ------------------- Configuration pour Décaler à Gauche. (384) ---------------- 
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 230); Ecrire_un_Entier_en_EEPROM(PTR, 430); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 392); Ecrire_un_Entier_en_EEPROM(PTR, 190); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 258); Ecrire_un_Entier_en_EEPROM(PTR, 287); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 334); Ecrire_un_Entier_en_EEPROM(PTR, 346); // Jambe D.
  Afficher_PTR();
  //---------------- Posture enregistrée (VEILLE) --------------- (408) ---------------
  Ecrire_un_Entier_en_EEPROM(PTR, 239); Ecrire_un_Entier_en_EEPROM(PTR, 315); Ecrire_un_Entier_en_EEPROM(PTR, 421); // Jambe A.
  Ecrire_un_Entier_en_EEPROM(PTR, 344); Ecrire_un_Entier_en_EEPROM(PTR, 296); Ecrire_un_Entier_en_EEPROM(PTR, 192); // Jambe B.
  Ecrire_un_Entier_en_EEPROM(PTR, 222); Ecrire_un_Entier_en_EEPROM(PTR, 298); Ecrire_un_Entier_en_EEPROM(PTR, 426); // Jambe C.
  Ecrire_un_Entier_en_EEPROM(PTR, 346); Ecrire_un_Entier_en_EEPROM(PTR, 291); Ecrire_un_Entier_en_EEPROM(PTR, 199); // Jambe D.
  Afficher_PTR();
  //--------- Enregistrement d'un balayage télémétrique---------- (432) ---------------
  Ecrire_un_OCTET_en_EEPROM(PTR, 28); Ecrire_un_OCTET_en_EEPROM(PTR, 27); Ecrire_un_OCTET_en_EEPROM(PTR, 26);
  Ecrire_un_OCTET_en_EEPROM(PTR, 25); Ecrire_un_OCTET_en_EEPROM(PTR, 24); Ecrire_un_OCTET_en_EEPROM(PTR, 22);
  Ecrire_un_OCTET_en_EEPROM(PTR, 20); Ecrire_un_OCTET_en_EEPROM(PTR, 17); Ecrire_un_OCTET_en_EEPROM(PTR, 13);
  Ecrire_un_OCTET_en_EEPROM(PTR, 12); Ecrire_un_OCTET_en_EEPROM(PTR, 10); Ecrire_un_OCTET_en_EEPROM(PTR, 8);
  Ecrire_un_OCTET_en_EEPROM(PTR, 8); Ecrire_un_OCTET_en_EEPROM(PTR, 6); Ecrire_un_OCTET_en_EEPROM(PTR, 6); 
  Ecrire_un_OCTET_en_EEPROM(PTR, 5); Ecrire_un_OCTET_en_EEPROM(PTR, 5); Ecrire_un_OCTET_en_EEPROM(PTR, 6);
  Ecrire_un_OCTET_en_EEPROM(PTR, 6); Ecrire_un_OCTET_en_EEPROM(PTR, 7); Ecrire_un_OCTET_en_EEPROM(PTR, 7);
  Ecrire_un_OCTET_en_EEPROM(PTR, 8); Ecrire_un_OCTET_en_EEPROM(PTR, 9); Ecrire_un_OCTET_en_EEPROM(PTR, 10);
  Ecrire_un_OCTET_en_EEPROM(PTR, 12); Ecrire_un_OCTET_en_EEPROM(PTR, 14); Ecrire_un_OCTET_en_EEPROM(PTR, 16);
  Ecrire_un_OCTET_en_EEPROM(PTR, 18); Ecrire_un_OCTET_en_EEPROM(PTR, 21); Ecrire_un_OCTET_en_EEPROM(PTR, 22);
  Ecrire_un_OCTET_en_EEPROM(PTR, 23); Ecrire_un_OCTET_en_EEPROM(PTR, 23); Afficher_PTR();
  //----------------- Spectre colorimétrique ---------------------- (464) ----------------
  Ecrire_un_Entier_en_EEPROM(PTR, 751);
  Ecrire_un_Entier_en_EEPROM(PTR, 594); Ecrire_un_Entier_en_EEPROM(PTR, 482); Ecrire_un_Entier_en_EEPROM(PTR, 531);
  Ecrire_un_Entier_en_EEPROM(PTR, 632); Ecrire_un_Entier_en_EEPROM(PTR, 692); Ecrire_un_Entier_en_EEPROM(PTR, 642);
  Afficher_PTR();
  //------------------------ Effacer les 3 premier programmes ----------------------------
  Ecrire_un_OCTET_en_EEPROM(480, 0); Ecrire_un_OCTET_en_EEPROM(512, 0); Ecrire_un_OCTET_en_EEPROM(544, 0);
    //------------------------- Inscrire le programme n°4 --------------------------------
  PTR = 576; Ecrire_un_CODE_en_EEPROM(21); Ecrire_un_CODE_en_EEPROM(55); Ecrire_un_CODE_en_EEPROM(54);
  Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(28);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(28); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(27);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(28); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(28);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(28);
  //-------------------------- Inscrire le programme n°5 ---------------------------------
  PTR = 608; Ecrire_un_CODE_en_EEPROM(26); Ecrire_un_CODE_en_EEPROM(26); Ecrire_un_CODE_en_EEPROM(54);
  Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90);  
  Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30);  
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90);  
  Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(25);  
  //-------------------------- Inscrire le programme n°6 ---------------------------------
  PTR = 640; Ecrire_un_CODE_en_EEPROM(21); Ecrire_un_CODE_en_EEPROM(55); Ecrire_un_CODE_en_EEPROM(54);
  Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(28);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(28); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(27);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(28); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(28);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(27); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(28);
  //-------------------------- Inscrire le programme n°7 ---------------------------------
  PTR = 672; Ecrire_un_CODE_en_EEPROM(26); Ecrire_un_CODE_en_EEPROM(26); Ecrire_un_CODE_en_EEPROM(54);
  Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90);  
  Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(90);
  Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30);  
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29); Ecrire_un_CODE_en_EEPROM(90);  
  Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(29);
  Ecrire_un_CODE_en_EEPROM(90); Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(25);  
  //-------------------------- Inscrire le programme n°8 ---------------------------------
  PTR = 704; Ecrire_un_CODE_en_EEPROM(30); Ecrire_un_CODE_en_EEPROM(61); Ecrire_un_CODE_en_EEPROM(55);
  Ecrire_un_CODE_en_EEPROM(21); Ecrire_un_CODE_en_EEPROM(14); Ecrire_un_CODE_en_EEPROM(3);
  Ecrire_un_CODE_en_EEPROM(3); Ecrire_un_CODE_en_EEPROM(3); Ecrire_un_CODE_en_EEPROM(3);
  Ecrire_un_CODE_en_EEPROM(3); Ecrire_un_CODE_en_EEPROM(3); Ecrire_un_CODE_en_EEPROM(3);
  Ecrire_un_CODE_en_EEPROM(3); Ecrire_un_CODE_en_EEPROM(3); Ecrire_un_CODE_en_EEPROM(4);
  Ecrire_un_CODE_en_EEPROM(4); Ecrire_un_CODE_en_EEPROM(4); Ecrire_un_CODE_en_EEPROM(4);
  Ecrire_un_CODE_en_EEPROM(4); Ecrire_un_CODE_en_EEPROM(8); Ecrire_un_CODE_en_EEPROM(8);
  Ecrire_un_CODE_en_EEPROM(8); Ecrire_un_CODE_en_EEPROM(8); Ecrire_un_CODE_en_EEPROM(8);
  Ecrire_un_CODE_en_EEPROM(7); Ecrire_un_CODE_en_EEPROM(7); Ecrire_un_CODE_en_EEPROM(7);
  Ecrire_un_CODE_en_EEPROM(7); Ecrire_un_CODE_en_EEPROM(7); Ecrire_un_CODE_en_EEPROM(14);
  Ecrire_un_CODE_en_EEPROM(61);
  //-------------------------- Inscrire le programme n°9 ---------------------------------
  PTR = 736; Ecrire_un_CODE_en_EEPROM(13); Ecrire_un_CODE_en_EEPROM(61); Ecrire_un_CODE_en_EEPROM(55);
  Ecrire_un_CODE_en_EEPROM(22); Ecrire_un_CODE_en_EEPROM(21); Ecrire_un_CODE_en_EEPROM(10);
  Ecrire_un_CODE_en_EEPROM(11); Ecrire_un_CODE_en_EEPROM(16); Ecrire_un_CODE_en_EEPROM(17);
  Ecrire_un_CODE_en_EEPROM(15); Ecrire_un_CODE_en_EEPROM(9); Ecrire_un_CODE_en_EEPROM(1);
  Ecrire_un_CODE_en_EEPROM(14); Ecrire_un_CODE_en_EEPROM(61);
  //------------------- Posture enregistrée n°1 (Neutres opérationnels) ------------------ 
  PTR = 768;
  Ecrire_une_Consigne_en_EEPROM(320); Ecrire_une_Consigne_en_EEPROM(308); Ecrire_une_Consigne_en_EEPROM(316); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(289); Ecrire_une_Consigne_en_EEPROM(303); Ecrire_une_Consigne_en_EEPROM(314); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(262); Ecrire_une_Consigne_en_EEPROM(292); Ecrire_une_Consigne_en_EEPROM(310); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(300); Ecrire_une_Consigne_en_EEPROM(285); Ecrire_une_Consigne_en_EEPROM(307); // Jambe D.
  //-------------------- Posture enregistrée n°2 (JEKERT posée au sol) ------------------- 
  PTR = 800;
  Ecrire_une_Consigne_en_EEPROM(239); Ecrire_une_Consigne_en_EEPROM(315); Ecrire_une_Consigne_en_EEPROM(429); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(344); Ecrire_une_Consigne_en_EEPROM(296); Ecrire_une_Consigne_en_EEPROM(192); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(222); Ecrire_une_Consigne_en_EEPROM(298); Ecrire_une_Consigne_en_EEPROM(426); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(346); Ecrire_une_Consigne_en_EEPROM(291); Ecrire_une_Consigne_en_EEPROM(199); // Jambe D.
  //-------------------- Posture enregistrée n°3 (Stable TRANSVERSAL) -------------------- 
  PTR = 832;
  Ecrire_une_Consigne_en_EEPROM(239); Ecrire_une_Consigne_en_EEPROM(213); Ecrire_une_Consigne_en_EEPROM(307); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(344); Ecrire_une_Consigne_en_EEPROM(414); Ecrire_une_Consigne_en_EEPROM(314); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(222); Ecrire_une_Consigne_en_EEPROM(215); Ecrire_une_Consigne_en_EEPROM(319); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(346); Ecrire_une_Consigne_en_EEPROM(388); Ecrire_une_Consigne_en_EEPROM(326); // Jambe D.
  //-------------------- Posture enregistrée n°4 (JEKERT posée au sol) ------------------- 
  PTR = 864;
  Ecrire_une_Consigne_en_EEPROM(239); Ecrire_une_Consigne_en_EEPROM(315); Ecrire_une_Consigne_en_EEPROM(429); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(344); Ecrire_une_Consigne_en_EEPROM(296); Ecrire_une_Consigne_en_EEPROM(192); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(222); Ecrire_une_Consigne_en_EEPROM(298); Ecrire_une_Consigne_en_EEPROM(426); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(346); Ecrire_une_Consigne_en_EEPROM(291); Ecrire_une_Consigne_en_EEPROM(199); // Jambe D.
  //----------------------- Posture enregistrée n°5 (Paratonnerre) ----------------------- 
  PTR = 896;
  Ecrire_une_Consigne_en_EEPROM(225); Ecrire_une_Consigne_en_EEPROM(369); Ecrire_une_Consigne_en_EEPROM(139); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(352); Ecrire_une_Consigne_en_EEPROM(242); Ecrire_une_Consigne_en_EEPROM(492); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(208); Ecrire_une_Consigne_en_EEPROM(379); Ecrire_une_Consigne_en_EEPROM(155); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(362); Ecrire_une_Consigne_en_EEPROM(212); Ecrire_une_Consigne_en_EEPROM(492); // Jambe D.
  //------------------- Posture enregistrée n°6 (Antenne à grand gain) ------------------- 
  PTR = 928;
  Ecrire_une_Consigne_en_EEPROM(297); Ecrire_une_Consigne_en_EEPROM(309); Ecrire_une_Consigne_en_EEPROM(229); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(256); Ecrire_une_Consigne_en_EEPROM(296); Ecrire_une_Consigne_en_EEPROM(390); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(286); Ecrire_une_Consigne_en_EEPROM(295); Ecrire_une_Consigne_en_EEPROM(229); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(266); Ecrire_une_Consigne_en_EEPROM(284); Ecrire_une_Consigne_en_EEPROM(398); // Jambe D.
  //-------------------------- Posture enregistrée n°7 (T avant) ------------------------- 
  PTR = 960;
  Ecrire_une_Consigne_en_EEPROM(305); Ecrire_une_Consigne_en_EEPROM(309); Ecrire_une_Consigne_en_EEPROM(229); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(194); Ecrire_une_Consigne_en_EEPROM(290); Ecrire_une_Consigne_en_EEPROM(390); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(394); Ecrire_une_Consigne_en_EEPROM(295); Ecrire_une_Consigne_en_EEPROM(229); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(260); Ecrire_une_Consigne_en_EEPROM(284); Ecrire_une_Consigne_en_EEPROM(398); // Jambe D.
  //---------------------- Posture enregistrée n°8 (Brasse arrière) ----------------------
  PTR = 992;
  Ecrire_une_Consigne_en_EEPROM(225); Ecrire_une_Consigne_en_EEPROM(309); Ecrire_une_Consigne_en_EEPROM(229); // Jambe A.
  Ecrire_une_Consigne_en_EEPROM(194); Ecrire_une_Consigne_en_EEPROM(290); Ecrire_une_Consigne_en_EEPROM(390); // Jambe B.
  Ecrire_une_Consigne_en_EEPROM(394); Ecrire_une_Consigne_en_EEPROM(295); Ecrire_une_Consigne_en_EEPROM(229); // Jambe C.
  Ecrire_une_Consigne_en_EEPROM(364); Ecrire_une_Consigne_en_EEPROM(284); Ecrire_une_Consigne_en_EEPROM(398); // Jambe D.
  //--------------------------------------------------------------------------------------
  
Juste_LIRE_EEPROM:  
  Lister_EEPROM();
  Infini: goto Infini;}
  
void Ecrire_un_CODE_en_EEPROM(byte CODE) {
  eeprom_write_byte((unsigned char *) PTR, CODE); PTR++;}
  
void Ecrire_un_OCTET_en_EEPROM(int ADRESSE, byte OCTET) {
   eeprom_write_byte((unsigned char *) ADRESSE, OCTET); PTR++;}
  
void Ecrire_un_Entier_en_EEPROM(int ADRESSE, int MOT16Bits) { // Pointe l'octet libre suivant.
   eeprom_write_word((unsigned int *) ADRESSE, MOT16Bits); PTR++; PTR++;}

void Ecrire_une_Consigne_en_EEPROM(int MOT16Bits) { // Pointe l'octet libre suivant.
   eeprom_write_word((unsigned int *) PTR, MOT16Bits); PTR++; PTR++;}
   
int Lire_un_Entier_en_EEPROM(int ADRESSE) {
  return eeprom_read_word((unsigned int *) ADRESSE);}

byte Lire_un_OCTET_en_EEPROM(int ADRESSE) {
  return eeprom_read_byte((unsigned char *) ADRESSE);} 
  
void Afficher_PTR() {Serial.println(); Serial.print("PTR = "); Serial.print(PTR);}

void Lister_EEPROM() {
  PTR = 0;
  Lister_un_BLOC();Lister_un_BLOC();
  Lister_un_BLOC();Lister_un_BLOC(); }
  
void Lister_un_BLOC() {
  Lister_ENTETE();
  byte Compteur_lignes = 0;
  while (Compteur_lignes < 16)
    {Lister_une_LIGNE(); Compteur_lignes++; } }
  
void Lister_une_LIGNE() {   
  byte Compteur_Octets = 0; Serial.print(' ');
  if (PTR<10) {Serial.print('0');};
  if (PTR<100) {Serial.print('0');};
  if (PTR<1000) {Serial.print('0');};
  Serial.print(PTR); Serial.print("  ");  
  while (Compteur_Octets < 16) {
    Lister_OCTET(); Compteur_Octets++; }
  Serial.println(); }
  
void Lister_ENTETE() {
   Serial.println();
   Serial.println(" ADRS  00 01 02 03 04 05 06 07 08 09 0A 0B 0C 0D 0E 0F");}
   
void Lister_OCTET() { 
  byte octet = Lire_un_OCTET_en_EEPROM(PTR); if (octet < 16)  Serial.print("0");
  Serial.print(octet,HEX); Serial.print(' '); PTR++; }
